==> huaweicloudsdkmoderation-3.0.2b0-py3-none-any.whl: huaweicloudsdkmoderation/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import ModerationClient
from huaweicloudsdkmoderation.v1.moderation_client import ModerationClient
# import models into sdk package
from huaweicloudsdkmoderation.v1.model.check_result_detail_body import CheckResultDetailBody
from huaweicloudsdkmoderation.v1.model.check_result_items_body import CheckResultItemsBody
from huaweicloudsdkmoderation.v1.model.check_result_result_body import CheckResultResultBody
from huaweicloudsdkmoderation.v1.model.check_task_jobs_items_body import CheckTaskJobsItemsBody
from huaweicloudsdkmoderation.v1.model.image_batch_moderation_req import ImageBatchModerationReq
from huaweicloudsdkmoderation.v1.model.image_batch_moderation_result_body import ImageBatchModerationResultBody
from huaweicloudsdkmoderation.v1.model.image_detection_req import ImageDetectionReq
from huaweicloudsdkmoderation.v1.model.image_detection_result_body import ImageDetectionResultBody
from huaweicloudsdkmoderation.v1.model.run_check_result_request import RunCheckResultRequest
from huaweicloudsdkmoderation.v1.model.run_check_result_response import RunCheckResultResponse
from huaweicloudsdkmoderation.v1.model.run_check_task_jobs_request import RunCheckTaskJobsRequest
from huaweicloudsdkmoderation.v1.model.run_check_task_jobs_response import RunCheckTaskJobsResponse
from huaweicloudsdkmoderation.v1.model.run_image_batch_moderation_request import RunImageBatchModerationRequest
from huaweicloudsdkmoderation.v1.model.run_image_batch_moderation_response import RunImageBatchModerationResponse
from huaweicloudsdkmoderation.v1.model.run_image_moderation_request import RunImageModerationRequest
from huaweicloudsdkmoderation.v1.model.run_image_moderation_response import RunImageModerationResponse
from huaweicloudsdkmoderation.v1.model.run_task_sumbit_request import RunTaskSumbitRequest
from huaweicloudsdkmoderation.v1.model.run_task_sumbit_response import RunTaskSumbitResponse
from huaweicloudsdkmoderation.v1.model.run_text_moderation_request import RunTextModerationRequest
from huaweicloudsdkmoderation.v1.model.run_text_moderation_response import RunTextModerationResponse
from huaweicloudsdkmoderation.v1.model.task_sumbit_req import TaskSumbitReq
from huaweicloudsdkmoderation.v1.model.task_sumbit_result_body import TaskSumbitResultBody
from huaweicloudsdkmoderation.v1.model.text_detection_body import TextDetectionBody
from huaweicloudsdkmoderation.v1.model.text_detection_items_req import TextDetectionItemsReq
from huaweicloudsdkmoderation.v1.model.text_detection_req import TextDetectionReq

==> huaweicloudsdkmoderation-3.0.28b0-py3-none-any.whl: huaweicloudsdkmoderation/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import ModerationClient
from huaweicloudsdkmoderation.v1.moderation_client import ModerationClient
from huaweicloudsdkmoderation.v1.moderation_async_client import ModerationAsyncClient
# import models into sdk package
from huaweicloudsdkmoderation.v1.model.check_result_items_body import CheckResultItemsBody
from huaweicloudsdkmoderation.v1.model.check_result_result_body import CheckResultResultBody
from huaweicloudsdkmoderation.v1.model.check_task_jobs_items_body import CheckTaskJobsItemsBody
from huaweicloudsdkmoderation.v1.model.image_batch_moderation_req import ImageBatchModerationReq
from huaweicloudsdkmoderation.v1.model.image_batch_moderation_result_body import ImageBatchModerationResultBody
from huaweicloudsdkmoderation.v1.model.image_detection_req import ImageDetectionReq
from huaweicloudsdkmoderation.v1.model.image_detection_result_body import ImageDetectionResultBody
from huaweicloudsdkmoderation.v1.model.image_detection_result_detail import ImageDetectionResultDetail
from huaweicloudsdkmoderation.v1.model.image_detection_result_detail_face_detail import ImageDetectionResultDetailFaceDetail
from huaweicloudsdkmoderation.v1.model.image_detection_result_detail_politics import ImageDetectionResultDetailPolitics
from huaweicloudsdkmoderation.v1.model.image_detection_result_detail_porn import ImageDetectionResultDetailPorn
from huaweicloudsdkmoderation.v1.model.run_check_result_request import RunCheckResultRequest
from huaweicloudsdkmoderation.v1.model.run_check_result_response import RunCheckResultResponse
from huaweicloudsdkmoderation.v1.model.run_check_task_jobs_request import RunCheckTaskJobsRequest
from huaweicloudsdkmoderation.v1.model.run_check_task_jobs_response import RunCheckTaskJobsResponse
from huaweicloudsdkmoderation.v1.model.run_image_batch_moderation_request import RunImageBatchModerationRequest
from huaweicloudsdkmoderation.v1.model.run_image_batch_moderation_response import RunImageBatchModerationResponse
from huaweicloudsdkmoderation.v1.model.run_image_moderation_request import RunImageModerationRequest
from huaweicloudsdkmoderation.v1.model.run_image_moderation_response import RunImageModerationResponse
from huaweicloudsdkmoderation.v1.model.run_task_sumbit_request import RunTaskSumbitRequest
from huaweicloudsdkmoderation.v1.model.run_task_sumbit_response import RunTaskSumbitResponse
from huaweicloudsdkmoderation.v1.model.run_text_moderation_request import RunTextModerationRequest
from huaweicloudsdkmoderation.v1.model.run_text_moderation_response import RunTextModerationResponse
from huaweicloudsdkmoderation.v1.model.task_sumbit_req import TaskSumbitReq
from huaweicloudsdkmoderation.v1.model.task_sumbit_result_body import TaskSumbitResultBody
from huaweicloudsdkmoderation.v1.model.text_detection_body import TextDetectionBody
from huaweicloudsdkmoderation.v1.model.text_detection_items_req import TextDetectionItemsReq
from huaweicloudsdkmoderation.v1.model.text_detection_req import TextDetectionReq
